intelmq.bots.collectors.kafka namespace — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.kafka namespace

## Submodules

## intelmq.bots.collectors.kafka.collector module

Kafka Collector Bot

Collects information from the Apache Kafka distributed stream processing system.

param topic

  topic to collect information from

type topic

  str

param bootstrap_servers

  the ‘host[:port]’ string of the Apache Kafka system. Defaults to localhost:9092

type bootstrap_servers

  str

`intelmq.bots.collectors.kafka.collector.` `BOT`

  alias of `intelmq.bots.collectors.kafka.collector.KafkaCollectorBot`

class `intelmq.bots.collectors.kafka.collector.` `KafkaCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()

    Fetch messages from the Kafka server and pass them on one by one